@@ -1,7 +1,6 @@
 "ensembleNobs.ensembleData" <-
 function (x) 
 {
- class(x) <- "data.frame" 
- length(x$obs)
+ nrow(x)
 }
 
